FromStringLdapType

Trait FromStringLdapType 

pub trait FromStringLdapType {
    type Error;

    // Required method
    fn parse(
        entry_dn: &str,
        attribute_name: &str,
        value: String,
    ) -> Result<Self, Self::Error>
       where Self: Sized;
}
a primitive result that can be converted from an Ldap type that is returned as a String

Required Associated Types

type Error

the type of error when the conversion fails

Required Methods

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

parse this type from a String returned by an LDAP search

Errors

fails if the type could not be parsed

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl FromStringLdapType for ObjectIdentifier

Source

type Error = UnexpectedStringValue

Source

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Source

impl FromStringLdapType for String

Source

type Error = Infallible

Source

fn parse( _entry_dn: &str, _attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Source

impl FromStringLdapType for bool

Source

type Error = UnexpectedStringValue

Source

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Source

impl FromStringLdapType for i8

Source

type Error = UnexpectedStringValue

Source

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Source

impl FromStringLdapType for i16

Source

type Error = UnexpectedStringValue

Source

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Source

impl FromStringLdapType for i32

Source

type Error = UnexpectedStringValue

Source

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Source

impl FromStringLdapType for i64

Source

type Error = UnexpectedStringValue

Source

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Source

impl FromStringLdapType for i128

Source

type Error = UnexpectedStringValue

Source

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Source

impl FromStringLdapType for isize

Source

type Error = UnexpectedStringValue

Source

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Source

impl FromStringLdapType for u8

Source

type Error = UnexpectedStringValue

Source

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Source

impl FromStringLdapType for u16

Source

type Error = UnexpectedStringValue

Source

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Source

impl FromStringLdapType for u32

Source

type Error = UnexpectedStringValue

Source

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Source

impl FromStringLdapType for u64

Source

type Error = UnexpectedStringValue

Source

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Source

impl FromStringLdapType for u128

Source

type Error = UnexpectedStringValue

Source

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Source

impl FromStringLdapType for usize

Source

type Error = UnexpectedStringValue

Source

fn parse( entry_dn: &str, attribute_name: &str, value: String, ) -> Result<Self, Self::Error>
where Self: Sized,

Implementors

Source

impl FromStringLdapType for DistinguishedName

Available on crate feature chumsky only.